" vim: set tw=80 :

" SETTINGS

" set relative line numbers
set number relativenumber

" set highlighting and continous search
set hlsearch incsearch

" show n-column limiter when textwidth is set
set colorcolumn=+1

" prevent terminal buffers to be closed when changing buffer
autocmd TermOpen * set bufhidden=hide

" remove line numbers to terminale
autocmd TermOpen * set nornu nonu

" set autoindent on`
set autoindent

" Make :find work on all files in :pwd
set path+=**

" ADDITIONAL COMMANDS

" make escape work in terminal and send ESC to terminal with C-Esc
tnoremap <Esc> <C-\><C-n>
tnoremap <C-Esc> <Esc>

" clear search with F2
nnoremap <F2> noh

" Use "," as leader
let mapleader = ","

" Switch between Windows with: Leader w
nnoremap <Leader>w <C-w><C-w>

" Show next buffer with: Leader n
nnoremap <Leader>n :bn<cr>

" Delete buffer with: Leader d
nnoremap <Leader>d :bd<cr>

" clear trailing spaces with: Leader t s
nnoremap <Leader>ts :%s/\s *$//g<CR>

" Reload config with: Leader R
nnoremap <Leader>R :source ~/.config/nvim/init.vim<cr>

" show Vim's true competitor with: Leader r c m
nnoremap <Leader>rcm :!open https://youtu.be/jn40Ugz0vuk<CR><CR>

" COLORSCHEME

" set colorscheme to onedark.im for nvim and airline
packadd! onedark.vim
colorscheme onedark
let g:airline_theme='onedark'

" PACKAGES

" vim-fish setup
syntax enable
filetype plugin indent on
" Set up :make to use fish for syntax checking.
autocmd FileType fish compiler fish

if has("vms")
  set nobackup		" do not keep a backup file, use versions instead
else
  set backup		" keep a backup file (restore to previous version)
  if has('persistent_undo')
    set undofile	" keep an undo file (undo changes after closing)
  endif
endif

